#!/bin/sh

#####################################################################################
#                                                                                   #
# erzeugt aus OSM-Daten Karten für Garmin-GPS inklusive SRTM-Höhenlinien            #
#                                                                                   #
# Erklärungen unter                                                                 #
#                                                                                   #
#    http://dirk.schimansky.com/OSM/                                                #
#                                                                                   #
# eigene_Karte.sh vom 26.04.2010 - erste lauffähige Version                         #
# eigene_Karte.sh vom 05.02.2015 - jetzt mit SRTM-Höhenlinien                       #
# eigene_Karte.sh vom 30.10.2017 - getrennte OSM-und SRTM-Karten für neuere Geräte  #
#                                - Zugang zu SRTM-Daten mit Anmeldung               #
#                                                                                   #
# web   : dirk.schimansky.com                                                       #
# e-mail: dirk@schimansky.com                                                       #
#                                                                                   #
# Quellen:                                                                          #
#  https://www.openstreetmap.org                                                    #
#  https://download.geofabrik.de                                                    #
#  https://www.nasa.gov/mission_pages/shuttle/shuttlemissions/archives/sts-99.html  #
#  https://www.kleineisel.de/blogs/index.php/osmmap/                                #
#                                                                                   #
#####################################################################################

########################################################################
########## Einstellungen an eigene Gegebenheiten anpassen ##############
########################################################################

# nachfolgend nur EINE (!) ROHDATENURL aktivieren. Bei mehreren aktiven URLs
# wird die letzte genommen.

###
# Belgien
#KARTENNAME="Belgien";TOP=51.5;LEFT=2.5;BOTTOM=49.45;RIGHT=6.5;MAX_NODES="800000"
#ROHDATENURL="https://download.geofabrik.de/europe/belgium-latest.osm.pbf"
#ROHDATENURL="https://download.geofabrik.de/europe-latest.osm.pbf";AUSSCHNEIDEN="true"

###
# Chicago-Detroit (midwest)
#KARTENNAME="Chicago-Detroit";TOP=44.0;LEFT=-90.0;BOTTOM=39.0;RIGHT=-80.0;MAX_NODES="800000"
#ROHDATENURL="https://download.geofabrik.de/north-america/us-midwest-latest.osm.pbf";AUSSCHNEIDEN="true"
#ROHDATENURL="https://download.geofabrik.de/north-america-latest.osm.pbf";AUSSCHNEIDEN="true"

###
# China
#KARTENNAME="China";TOP=49.2;LEFT=73.5;BOTTOM=20.1;RIGHT=134.8;MAX_NODES="800000"
#ROHDATENURL="https://download.geofabrik.de/asia/china-latest.osm.pbf"
#ROHDATENURL="https://download.geofabrik.de/asia-latest.osm.pbf";AUSSCHNEIDEN="true"

###
# DACH (Deutschland, Österreich und Schweiz)
# die Karte ist ziemlich groß, über 3 GByte (Stand Juni 2022). Ohne POI und SRTM. Habe die Karte
# selber nie ausprobiert, das müsst Ihr selber machen. Vielleicht ist es auch besser die Einzelkarten
# von Deutschland, Österreich und der Schweiz zu benutzen.
#KARTENNAME="DACH";TOP=55.2;LEFT=5.9;BOTTOM=45.7;RIGHT=17.5;MAX_NODES="800000"
#ROHDATENURL="https://download.geofabrik.de/europe-latest.osm.pbf";AUSSCHNEIDEN="true"

###
# Daenemark
#KARTENNAME="Daenemark";TOP=57.46;LEFT=12.5;BOTTOM=54.32;RIGHT=7.3;MAX_NODES="800000"
#ROHDATENURL="https://download.geofabrik.de/europe/denmark-latest.osm.pbf"
#ROHDATENURL="https://download.geofabrik.de/europe-latest.osm.pbf";AUSSCHNEIDEN="true"

###
# Deutschland
KARTENNAME="Deutschland";TOP=55.2;LEFT=5.8;BOTTOM=47.2;RIGHT=15.1;MAX_NODES="800000"
ROHDATENURL="https://download.geofabrik.de/europe/germany-latest.osm.pbf"
#ROHDATENURL="https://download.geofabrik.de/europe-latest.osm.pbf";AUSSCHNEIDEN="true"

###
# Finnland
#KARTENNAME="Finnland";TOP=70.4;LEFT=19;BOTTOM=59.6;RIGHT=31.7;MAX_NODES="800000"
#ROHDATENURL="https://download.geofabrik.de/europe/finland-latest.osm.pbf"
#ROHDATENURL="https://download.geofabrik.de/europe-latest.osm.pbf";AUSSCHNEIDEN="true"

###
# Frankreich
#KARTENNAME="Frankreich";TOP=51.3;LEFT=-5.4;BOTTOM=42.3;RIGHT=8.4;MAX_NODES="800000"
#ROHDATENURL="https://download.geofabrik.de/europe/france-latest.osm.pbf"
#ROHDATENURL="https://download.geofabrik.de/europe-latest.osm.pbf";AUSSCHNEIDEN="true"

###
# Italien (mit Sizilien)
#KARTENNAME="Italien";TOP=47.1;LEFT=6.6;BOTTOM=36.6;RIGHT=18.6;MAX_NODES="800000"
#ROHDATENURL="https://download.geofabrik.de/europe/italy-latest.osm.pbf"
#ROHDATENURL="https://download.geofabrik.de/europe-latest.osm.pbf";AUSSCHNEIDEN="true"

###
# Japan
#KARTENNAME="Japan";TOP=46.0;LEFT=126.5;BOTTOM=25.0;RIGHT=146.0;MAX_NODES="800000"
#ROHDATENURL="https://download.geofabrik.de/asia/japan-latest.osm.pbf"
#ROHDATENURL="https://download.geofabrik.de/asia-latest.osm.pbf";AUSSCHNEIDEN="true"

###
# Jordanien
#KARTENNAME="Jordanien";TOP=33.5;LEFT=34.8;BOTTOM=29.1;RIGHT=39.4;MAX_NODES="800000"
#ROHDATENURL="https://download.geofabrik.de/asia/jordan-latest.osm.pbf"

###
# Kroatien
#KARTENNAME="Kroatien";TOP=46.6;LEFT=13.3;BOTTOM=42.1;RIGHT=19.7;MAX_NODES="800000"
#ROHDATENURL="https://download.geofabrik.de/europe/croatia-latest.osm.pbf"
#ROHDATENURL="https://download.geofabrik.de/europe-latest.osm.pbf";AUSSCHNEIDEN="true"

###
# Luxemburg
#KARTENNAME="Luxemburg";TOP=50.2;LEFT=5.6;BOTTOM=49.3;RIGHT=6.6;MAX_NODES="800000"
#ROHDATENURL="https://download.geofabrik.de/europe/luxembourg-latest.osm.pbf"
#ROHDATENURL="https://download.geofabrik.de/europe-latest.osm.pbf";AUSSCHNEIDEN="true"

###
# Niederlande
#KARTENNAME="Niederlande";TOP=53.8;LEFT=3.25;BOTTOM=50.7;RIGHT=7.3;MAX_NODES="800000"
#ROHDATENURL="https://download.geofabrik.de/europe/netherlands-latest.osm.pbf"
#ROHDATENURL="https://download.geofabrik.de/europe-latest.osm.pbf";AUSSCHNEIDEN="true"

###
# Norwegen
#KARTENNAME="Norwegen";TOP=71;LEFT=3;BOTTOM=53;RIGHT=32;MAX_NODES="800000"
#ROHDATENURL="https://download.geofabrik.de/europe/norway-latest.osm.pbf"
#ROHDATENURL="https://download.geofabrik.de/europe-latest.osm.pbf";AUSSCHNEIDEN="true"

###
# Österreich
#KARTENNAME="Oesterreich";TOP=49.0;LEFT=9.0;BOTTOM=46.2;RIGHT=17.5;MAX_NODES="800000"
#ROHDATENURL="https://download.geofabrik.de/europe/austria-latest.osm.pbf"
#ROHDATENURL="https://download.geofabrik.de/europe-latest.osm.pbf";AUSSCHNEIDEN="true"

###
# Philippinen
#KARTENNAME="Philippinen";TOP=20.8;LEFT=114.7;BOTTOM=5.3;RIGHT=127.2;MAX_NODES="800000"
#ROHDATENURL="https://download.geofabrik.de/asia/philippines-latest.osm.pbf"
#ROHDATENURL="https://download.geofabrik.de/asia-latest.osm.pbf";AUSSCHNEIDEN="true"

###
# Portugal
#KARTENNAME="Portugal";TOP=42.9;LEFT=-11.25;BOTTOM=36.75;RIGHT=6.15;MAX_NODES="800000"
#ROHDATENURL="https://download.geofabrik.de/europe/portugal-latest.osm.pbf"
#ROHDATENURL="https://download.geofabrik.de/europe-latest.osm.pbf";AUSSCHNEIDEN="true"

###
# Skandinavien (Norwegen, Schweden, Finnland und auch Daenemark)
#KARTENNAME="Skandinavien";TOP=71;LEFT=3;BOTTOM=53;RIGHT=32;MAX_NODES="800000"
#ROHDATENURL="https://download.geofabrik.de/europe-latest.osm.pbf";AUSSCHNEIDEN="true"

###
# Schweiz
#KARTENNAME="Schweiz";TOP=48;LEFT=6;BOTTOM=45;RIGHT=11;MAX_NODES="800000"
#ROHDATENURL="https://download.geofabrik.de/europe/switzerland-latest.osm.pbf"
#ROHDATENURL="https://download.geofabrik.de/europe-latest.osm.pbf";AUSSCHNEIDEN="true"

###
# Schweden
#KARTENNAME="Schweden";TOP=70.3;LEFT=10;BOTTOM=58.8;RIGHT=25;MAX_NODES="800000"
#ROHDATENURL="https://download.geofabrik.de/europe/sweden-latest.osm.pbf"

###
# St. Petersburg
#KARTENNAME="St.Petersburg";TOP=60.1;LEFT=29.3;BOTTOM=59.3;RIGHT=30.5;MAX_NODES="800000"
#ROHDATENURL="https://download.geofabrik.de/russia-latest.osm.pbf";AUSSCHNEIDEN="true"
#ROHDATENURL="https://download.geofabrik.de/europe-latest.osm.pbf";AUSSCHNEIDEN="true"

###
# Spanien
#KARTENNAME="Spanien";TOP=44.0;LEFT=-11.25;BOTTOM=35.5;RIGHT=5.5;MAX_NODES="800000"
#ROHDATENURL="https://download.geofabrik.de/europe/spain-latest.osm.pbf"
#ROHDATENURL="https://download.geofabrik.de/europe-latest.osm.pbf";AUSSCHNEIDEN="true"

###
# Türkei
#KARTENNAME="Tuerkei";TOP=42.8;LEFT=26.2;BOTTOM=36.3;RIGHT=43.3;MAX_NODES="800000"
#ROHDATENURL="https://download.geofabrik.de/europe/turkey-latest.osm.pbf"
#ROHDATENURL="https://download.geofabrik.de/europe-latest.osm.pbf";AUSSCHNEIDEN="true"

###
# UK und Irland
#KARTENNAME="UK+IRL";TOP=59.2;LEFT=-10.5;BOTTOM=49.5;RIGHT=2.0;MAX_NODES="800000"
#ROHDATENURL="https://download.geofabrik.de/europe-latest.osm.pbf";AUSSCHNEIDEN="true"

###
# das TYP-File
# definiert das Aussehen der Karte. Es muss als txt-File vorliegen, damit mkgmap die family-id ändern kann.
# Dadurch bekommt jede Karte eine andere Family-ID, damit man mehrere Karten ins GPS-Gerät laden und dort
# ein- und ausschalten kann.
# Das txt-File muss in ${STARTDIR}/styles liegen
TYPFILE="DirkS"		# meine eigenes, sieht meiner Meinung nach hübsch aus ...

###
# Rohdaten neu von download.geofabrik.de laden? (default=false)
# Wenn lokal noch keine Rohdaten vorhanden sind werden sie auf jeden Fall geladen. Sind allerdings
# schon Rohdaten lokal vorhanden werden diese verwendet.
# Für die ersten Versuche würde ich den DOWNLOAD ausgeschaltet lassen - es muss nicht für jeden
# Probelauf das neueste Kartenmaterial geladen werden. Später - wenn alles wunschgemäß läuft - kann
# man den Download immer noch einschalten.
#DOWNLOAD="true"

###
# Zugang zu den SRTM-Daten der NASA. Ohne einen eigenen Accout geht's seit 2017 leider nicht mehr.
# Auch sind die Daten jetzt nicht mehr bei der NASA direkt abrufbar, sondern hier bei der USGS
# (United States Geological Survey). Hier kann man sich registrieren, damit phyghtmap Daten abrufen
# kann:
#
#    https://ers.cr.usgs.gov/register
#
# Macht es, meldet Euch an! Es ist kostenlos, einfach und geht recht schnell. Und registriert könnt
# Ihr wirklich weltweit Höhenkarten erzeugen lassen.
#
# Die Anmeldedaten tragt Ihr dann hier ein:
EARTHEXPLORERUSER="dummy-user"
EARTHEXPLORERPASSWORD="dummy-password"

###
# nach der Kartenerzeugung aufraeumen? ("no", also "nicht aufräumen", erleichtert die Fehlersuche, wenn mal was nicht klappt)
AUFRAEUMEN="yes"	# [yes|no (default)]

###
# manuell installierte Anwendungen
APP_splitter="/usr/OSM/splitter/splitter.jar"
APP_mkgmap="/usr/OSM/mkgmap/mkgmap.jar"
APP_gmaptool="/usr/OSM/gmaptool/gmt"
# aus Repositories installierte Anwendungen
APP_wget=`which wget`
APP_osmosis=`which osmosis`
APP_phyghtmap=`which phyghtmap`
APP_java="/etc/alternatives/java"

###
# maximaler Arbeitsspeicher für Java-Anwendungen
MEMORY="12000M"		# dafuer sollten min.  16 GByte RAM im Rechner installiert sein
#MEMORY="20000M"	# dafuer sollten min.  32 GByte RAM im Rechner installiert sein
#MEMORY="64000M"	# dafuer sollten min.  96 GByte RAM im Rechner installiert sein
#MEMORY="96000M"	# dafuer sollten min. 128 GByte RAM im Rechner installiert sein

###
# Für splitter, mkgmap & phyghtmap: Wieviele Prozesse gleichzeitig?
MAXPROCESSES=6

################################################################################################################
################################################################################################################
############### ab hier keine Änderungen mehr notwendig ########################################################
################################################################################################################
################################################################################################################

###
# Startzeit festhalten
STARTTIMEscript=`date +%s`

###
# Escape-Sequenzen für Fehlermeldungen:
BOLD="\033[1m"	# fett
BLINK="\033[5m"	# blinken
RED="\033[91m"	# rot
OFF="\033[0m"

###
# aktuelle Verzeichnis
STARTDIR=`pwd`

###
# Logs
LOGSCRIPT="${STARTDIR}/LOG-Script.txt"
LOGPRG="${STARTDIR}/LOG-PRG.txt"

###
# los gehts
echo "`date +%X`: Starte Kartenerzeugung \"${KARTENNAME}\"\n" > "${LOGSCRIPT}"
echo "`date +%X`: Starte Kartenerzeugung \"${KARTENNAME}\"\n" > "${LOGPRG}"

###
# Arbeitspfad prüfen (in "${STARTDIR}/eigene_Karte_work" werden die eigentlichen Arbeiten verrichtet)
! [ -d "${STARTDIR}/eigene_Karte_work" ] && mkdir -p "${STARTDIR}/eigene_Karte_work"

################################################################################################################
################################################################################################################
############# Einstellungen sind erledigt, jetzt alles prüfen & vorbereiten ####################################
################################################################################################################
################################################################################################################
echo "`date +%X`: Prüfe notwendige Daten und Anwendungen:" >> "${LOGSCRIPT}"

echo -n "          --> Kartenname \"${KARTENNAME}\" ..." >> "${LOGSCRIPT}"
if [ -z "${KARTENNAME}" ];then
	echo " nicht festgelegt! ${BOLD}${BLINK}${RED}<---------- FEHLER!!${OFF}" >> "${LOGSCRIPT}"
	ABBRUCH="true"
else
	echo " ok!" >> "${LOGSCRIPT}"
fi

echo -n "          --> Rohdatenlink \"${ROHDATENURL}\" ..." >> "${LOGSCRIPT}"
if [ -z "${ROHDATENURL}" ];then
	echo " nicht festgelegt! ${BOLD}${BLINK}${RED}<---------- FEHLER!!${OFF}" >> "${LOGSCRIPT}"
	ABBRUCH="true"
else
	echo " ok!" >> "${LOGSCRIPT}"
fi

echo -n "          --> Typ-File \"${STARTDIR}/styles/typ-${TYPFILE}.txt\" ..." >> "${LOGSCRIPT}"
if ! [ -f "${STARTDIR}/styles/typ-${TYPFILE}.txt" ];then
	echo " fehlt! ${BOLD}${BLINK}${RED}<---------- FEHLER!!${OFF}" >> "${LOGSCRIPT}"
	ABBRUCH="true"
else
	echo " ok!" >> "${LOGSCRIPT}"
fi

for T in "OSM" "POI" "SRTM";do
	echo -n "          --> Style \"${STARTDIR}/styles/mkgmap-style-${T}\" ..." >> "${LOGSCRIPT}"
	if ! [ -d "${STARTDIR}/styles/mkgmap-style-${T}" ];then
		echo " fehlt! ${BOLD}${BLINK}${RED}<---------- FEHLER!!${OFF}" >> "${LOGSCRIPT}"
		ABBRUCH="true"
	else
		echo " ok!" >> "${LOGSCRIPT}"
	fi
done

echo    "          --> \${EARTHEXPLORERUSER} & \${EARTHEXPLORERPASSWORD} für Zugang zu den SRTM-Daten auf" >> "${LOGSCRIPT}"
echo    "              dem USGS-Server \" https://ers.cr.usgs.gov/register\" (wenn noch kein Account" >> "${LOGSCRIPT}"
echo -n "              vorhanden ist kann dort einer angelegt werden) ..." >> "${LOGSCRIPT}"
if [ -z "${EARTHEXPLORERUSER}" -o -z "${EARTHEXPLORERPASSWORD}" -o "${EARTHEXPLORERUSER}" = "dummy-user" -o "${EARTHEXPLORERPASSWORD}" = "dummy-password" ];then
	echo " nicht vorhanden, daher keine Höhenkartenerzeugung!" >> "${LOGSCRIPT}"
else
	echo " ok!" >> "${LOGSCRIPT}"
fi

check_app(){
	echo -n "          --> \"$1\" ..." >> "${LOGSCRIPT}"
	if ! [ -f "$1" ];then
		echo " fehlt! ${BOLD}${BLINK}${RED}<---------- FEHLER!!${OFF}" >> "${LOGSCRIPT}"
		ABBRUCH="true"
	else
		echo " ok!" >> "${LOGSCRIPT}"
	fi
}
check_app "${APP_phyghtmap}"
if [ -x `which phyghtmap` ];then
	PHYGHTMAPversion=`${APP_phyghtmap} -v | awk '{print$2}'`
	PHYGHTMAPversion=`echo "${PHYGHTMAPversion} * 100" | bc -l | awk -F. '{print$1}'`
	if [ "${PHYGHTMAPversion}" -lt "210" ];then
		echo "          --> \"`${APP_phyghtmap} -v`\": Es wird Version 2.10 oder höher benötigt! ${BOLD}${BLINK}${RED}<---------- FEHLER!!${OFF}" >> "${LOGSCRIPT}"
		ABBRUCH="true"
	else
		echo "          --> \"`${APP_phyghtmap} -v`\": Version ist 2.10 oder höher ... ok!" >> "${LOGSCRIPT}"
	fi
fi
check_app "${APP_splitter}"
check_app "${APP_mkgmap}"
check_app "${APP_gmaptool}"
check_app "${APP_osmosis}"
check_app "${APP_java}"
if [ "${ABBRUCH}" = "true" ];then
	echo "\n          Abbruch aufgrund fehlender Daten/Anwendungen!" >> "${LOGSCRIPT}"
	echo "\n          Abbruch aufgrund fehlender Daten/Anwendungen!" >> "${LOGPRG}"
	cat "${LOGSCRIPT}"
	echo
	sleep 3
	exit
	echo
else
	echo "          Ok, alles vorhanden!\n" >> "${LOGSCRIPT}"
fi

###
# das Zielverzeichnis pruefen und gegebenenfalls erzeugen
! [ -d "eigene_Karte_${KARTENNAME}" ] && mkdir "${STARTDIR}/eigene_Karte_${KARTENNAME}"

###
# aktuelles Verzeichnis festhalten und ins Arbeitsverzeichnis wechseln
cd "${STARTDIR}/eigene_Karte_work"

###
# Perl-Skript zum Runden erzeugen
echo "#!/usr/bin/perl" > "${STARTDIR}/eigene_Karte_work/round.pl"
echo "" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "if (\$ARGV[1]){\$DECIMALSgiven=\$ARGV[1];}" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "print &round(\$ARGV[0]);" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "exit;" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "sub round {" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "	my \$VALUE=\$_[0];" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "	\$UNIT[18]=\"EByte\";" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "	\$UNIT[15]=\"PByte\";" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "	\$UNIT[12]=\"TByte\";" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "	\$UNIT[9]=\"GByte\";" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "	\$UNIT[6]=\"MByte\";" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "	\$UNIT[3]=\"KByte\";" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "	\$UNIT[0]=\"Byte\";" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "	for (my \$DIGITS=12;\$DIGITS>=0;\$DIGITS-=3){" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "		if (\$VALUE>(10**\$DIGITS)){" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "			if (\$DECIMALSgiven){" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "				\$DECIMALS=\$DECIMALSgiven;" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "			} elsif (\$VALUE>(10**(\$DIGITS+2))){" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "				\$DECIMALS=0;" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "			} elsif (\$VALUE>(10**(\$DIGITS+1))){" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "				\$DECIMALS=1;" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "			} else {" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "				\$DECIMALS=2;" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "			}" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "			if (\$DECIMALS==0){" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "			    \$VALUE=&commify(sprintf(\"%.0f\",\$VALUE/(10**(\$DIGITS)))).\" \$UNIT[\$DIGITS]\";" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "			} else {" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "				\$VALUE=&commify(sprintf(\"%.\$DECIMALS\".\"f\",\$VALUE/(10**(\$DIGITS)))).\" \$UNIT[\$DIGITS]\";" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "			}" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "			last;" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "		}" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "	}" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "	return(\"\$VALUE\");" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "}" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "sub commify {" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "	my \$z = reverse \$_[0];" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "	\$z =~ s/\./,/;" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "	\$z =~ s/(\d\d\d)(?=\d)(?!\d*\,)/\$1./g;" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "	return scalar reverse \$z;" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "}" >> "${STARTDIR}/eigene_Karte_work/round.pl"
echo "" >> "${STARTDIR}/eigene_Karte_work/round.pl"

################################################################################################################
################################################################################################################
############### Los geht's: Typ-Files mit family-IDs erzeugen ##################################################
################################################################################################################
################################################################################################################

echo "`date +%X`: Erzeuge \"mytype.typ\" aus \"typ-${TYPFILE}.txt\" mit family-IDs" >> "${LOGSCRIPT}"
echo "\n###############################################################################################################" >> "${LOGPRG}"
echo "`date +%X`: Erzeuge \"mytype.typ\" aus \"typ-${TYPFILE}.txt\" mit family-IDs" >> "${LOGPRG}"
echo "###############################################################################################################" >> "${LOGPRG}"
make_FAMILYID(){
	VALUE=$1
	TYP=$2
	ID=`echo "${VALUE}-${TYP}" | md5sum | tr '[a-z]'  '[0-9]' | head -c4`
	while [ ${ID} -lt 1000 ];do
		ID=$((ID*10))
	done
	${APP_java} -jar ${APP_mkgmap} --family-id=${ID} "${STARTDIR}/styles/typ-${TYPFILE}.txt" >> "${LOGPRG}" 2>&1
	mv "typ-${TYPFILE}.typ" "${TYP}.typ"
}
make_FAMILYID "${KARTENNAME}" "OSM";FAMILYIDOSM="${ID}"
make_FAMILYID "${KARTENNAME}" "POI";FAMILYIDPOI="${ID}"
make_FAMILYID "${KARTENNAME}" "SRTM";FAMILYIDSRTM="${ID}"
echo "          --> ${KARTENNAME}-OSM : ${FAMILYIDOSM}" >> "${LOGSCRIPT}"
echo "          --> ${KARTENNAME}-POI : ${FAMILYIDPOI}" >> "${LOGSCRIPT}"
echo "          --> ${KARTENNAME}-SRTM: ${FAMILYIDSRTM}" >> "${LOGSCRIPT}"
echo "          --> ${KARTENNAME}-OSM : ${FAMILYIDOSM}" >> "${LOGPRG}"
echo "          --> ${KARTENNAME}-POI : ${FAMILYIDPOI}" >> "${LOGPRG}"
echo "          --> ${KARTENNAME}-SRTM: ${FAMILYIDSRTM}" >> "${LOGPRG}"
echo "" >> "${LOGSCRIPT}"

###
# Rohdaten holen/ermitteln
ROHDATEN=`basename ${ROHDATENURL}`

###
# Rohdaten löschen, damit sie neu geladen werden
[ "${DOWNLOAD}" = "true" -a -f "${ROHDATEN}" ] && rm "${ROHDATEN}"

###
# Download
DAUERdownload=0	# auf jeden Fall nullen, wird unten aus der Gesamtlaufzeit rausgerechnet
if [ ! -f "${ROHDATEN}" ];then
	echo -n "`date +%X`: Download der Rohdaten \"${ROHDATEN}\" " >> "${LOGSCRIPT}"
	echo -n "`date +%X`: Download der Rohdaten \"${ROHDATEN}\" " >> "${LOGPRG}"
	DOWNLOADstart=`date +%s`
	${APP_wget} ${ROHDATENURL} -O "${ROHDATEN}" -o "${LOGPRG}.download"
	#--limit-rate=5M
	DOWNLOADstop=`date +%s`
	[ -f "${STARTDIR}/eigene_Karte_${KARTENNAME}/${KARTENNAME}.OSM" ] && rm "${STARTDIR}/eigene_Karte_${KARTENNAME}/${KARTENNAME}.OSM"	# wenn neuer Download, dann auch alte Daten loeschen
	FILESIZE=`ls -l "${ROHDATEN}" | awk '{print$5}'`
	TRANSFERRATE=$((FILESIZE/(DOWNLOADstop-DOWNLOADstart)))
	if [ ${FILESIZE} = 0 ];then
		echo "Fehler!" >> "${LOGSCRIPT}"
		echo "\n`date +%X`: \"${ROHDATEN}\" hat Grösse ${FILESIZE} --> Abbruch!\n" >> "${LOGSCRIPT}"
		echo "\n`date +%X`: \"${ROHDATEN}\" hat Grösse ${FILESIZE} --> Abbruch!\n" >> "${LOGPRG}"
		exit
	else
		DAUERdownload=$((DOWNLOADstop-DOWNLOADstart))
		TRANSFERRATE=$((FILESIZE/(DOWNLOADstop-DOWNLOADstart)))
		DAUERdownload_hour=$((DAUERdownload/3600))
		DAUERdownload_min=$(((DAUERdownload-DAUERdownload_hour*3600)/60))
		DAUERdownload_sec=$(((DAUERdownload-DAUERdownload_hour*3600-DAUERdownload_min*60)))
		[ ${DAUERdownload_min} -lt 10 ] && DAUERdownload_min="0${DAUERdownload_min}"
		[ ${DAUERdownload_sec} -lt 10 ] && DAUERdownload_sec="0${DAUERdownload_sec}"
		DAUERdownload_txt="${DAUERdownload_hour}:${DAUERdownload_min}:${DAUERdownload_sec}"
		echo "in ${DAUERdownload_txt} --> `perl round.pl ${TRANSFERRATE}`/s" >> "${LOGSCRIPT}"
		echo "in ${DAUERdownload_txt} --> `perl round.pl ${TRANSFERRATE}`/s\n" >>"${LOGPRG}"
	fi
fi

###
# Rohdaten von wann?
ROHDATENDATUM=`date -r "${ROHDATEN}" +%x`
echo -n "`date +%X`: Verwende Rohdaten \"${ROHDATEN}\" vom ${ROHDATENDATUM} ... " >> "${LOGSCRIPT}"
echo -n "`date +%X`: Verwende Rohdaten \"${ROHDATEN}\" vom ${ROHDATENDATUM} ... " >> "${LOGPRG}"

###
# und die Größe?
FILESIZE=`ls -l "${ROHDATEN}" | awk '{print$5}'`
echo "`perl round.pl ${FILESIZE}`" >> "${LOGSCRIPT}"
echo "`perl round.pl ${FILESIZE}`" >> "${LOGPRG}"
if [ ${FILESIZE} = 0 ];then
	echo "\n            \"${ROHDATEN}\" hat Grösse ${FILESIZE} --> Abbruch!" >> "${LOGSCRIPT}"
	echo "\n            \"${ROHDATEN}\" hat Grösse ${FILESIZE} --> Abbruch!" >> "${LOGPRG}"
	exit
fi

###
# Filenamen zerlegen
EXTENSION=`echo ${ROHDATEN} | rev | awk -F. '{print$1}' | rev`
FILEBASE=`echo ${ROHDATEN} | awk -F. '{print$1}'`

###
# Bereich ausschneiden?
if [ "${AUSSCHNEIDEN}" = "true" ];then
	echo "`date +%X`: Aus \"${ROHDATEN}\" gewünschten Bereich \"${KARTENNAME}.pbf\" ausschneiden: " >> "${LOGSCRIPT}"
	echo "###############################################################################################################" >> "${LOGPRG}"
	echo "`date +%X`: Aus \"${ROHDATEN}\" gewünschten Bereich \"${KARTENNAME}.pbf\" ausschneiden: " >> "${LOGPRG}"
	echo "###############################################################################################################" >> "${LOGPRG}"
	if [ -f "${STARTDIR}/polygones/${KARTENNAME}.poly" ];then
		echo "          --> nutze \"--bounding-polygon file=${KARTENNAME}.poly\"" >> "${LOGSCRIPT}"
		BOUNDING="--bounding-polygon file=${STARTDIR}/polygones/${KARTENNAME}.poly completeWays=yes"
	else
		echo "          --> nutze \"--bounding-box left=${LEFT} right=${RIGHT} bottom=${BOTTOM} top=${TOP}\"" >> "${LOGSCRIPT}"
		BOUNDING="--bounding-box left=${LEFT} right=${RIGHT} bottom=${BOTTOM} top=${TOP} completeWays=yes"
	fi
	${APP_osmosis}														\
		--read-pbf "${STARTDIR}/eigene_Karte_work/${ROHDATEN}"			\
		${BOUNDING}														\
		--buffer														\
		--write-pbf file=${STARTDIR}/eigene_Karte_work/${KARTENNAME}.pbf					\
		>> "${LOGPRG}" 2>&1
	FILESIZE=`ls -l "${STARTDIR}/eigene_Karte_work/${KARTENNAME}.pbf" | awk '{print$5}'`
	echo "          --> \"${KARTENNAME}.pbf\" mit `perl round.pl ${FILESIZE}` erzeugt" >> "${LOGSCRIPT}"
	[ -f "konvertiert.OSM" ] && rm "konvertiert.OSM"
else
	echo "`date +%X`: \"${ROHDATEN}\" ist identisch mit gewünschtem Bereich \"${KARTENNAME}\"" >> "${LOGSCRIPT}"
	echo "          --> kein Ausschneiden notwendig!" >> "${LOGSCRIPT}"
	echo "          --> kopiere \"${ROHDATEN}\" nach \"${KARTENNAME}.pbf\"" >> "${LOGSCRIPT}"
	echo "###############################################################################################################" >> "${LOGPRG}"
	echo "`date +%X`: \"${ROHDATEN}\" ist identisch mit gewünschtem Bereich \"${KARTENNAME}\" --> kein Ausschneiden notwendig!" >> "${LOGPRG}"
	echo "          --> kein Ausschneiden notwendig!" >> "${LOGPRG}"
	echo "          --> kopiere \"${ROHDATEN}\" nach \"${KARTENNAME}.pbf\"" >> "${LOGPRG}"
	echo "###############################################################################################################" >> "${LOGPRG}"
	cp "${STARTDIR}/eigene_Karte_work/${ROHDATEN}" "${STARTDIR}/eigene_Karte_work/${KARTENNAME}.pbf"
fi

###
# Karte in Kacheln splitten (hier wird auch die template.args mit den IDs der einzelnen Kacheln erzeugt)
echo >> "${LOGSCRIPT}"
echo -n "`date +%X`: \"${KARTENNAME}.pbf\" für OSM-Karte in Kacheln splitten ..." >> "${LOGSCRIPT}"
echo "\n###############################################################################################################" >> "${LOGPRG}"
echo "`date +%X`: \"${KARTENNAME}.pbf\" für OSM-Karte in Kacheln splitten ..." >> "${LOGPRG}"
echo "###############################################################################################################" >> "${LOGPRG}"
"${APP_java}" -Xmx${MEMORY} -server -jar ${APP_splitter}				\
	--mapid=${FAMILYIDOSM}0001											\
	--mixed=yes															\
	--max-nodes=${MAX_NODES}											\
	--max-areas=8092													\
	--max-threads=${MAXPROCESSES}										\
	--keep-complete=true												\
	"${STARTDIR}/eigene_Karte_work/${KARTENNAME}.pbf"					\
	>> "${LOGPRG}" 2>&1
echo " ok!" >> "${LOGSCRIPT}"

###
# template.args dieses Splitterdurchlaufs sichern
mv -f "template.args" "${KARTENNAME}-OSM-template.args"

################################################################################################################
################################################################################################################
############### routingfähige OSM-Karte erstellen ohne Höhenlinien und POI #####################################
################################################################################################################
################################################################################################################

echo >> "${LOGSCRIPT}"
echo -n "`date +%X`: Erzeuge routingfähige OSM-Karte \"gmapsupp.img\" fürs GPS (ohne Höhenlinien und POIs) ..." >> "${LOGSCRIPT}"
echo "\n###############################################################################################################" >> "${LOGPRG}"
echo "`date +%X`: Erzeuge routingfähige OSM-Karte \"gmapsupp.img\" fürs GPS (ohne Höhenlinien und POIs) ..." >> "${LOGPRG}"
echo "###############################################################################################################" >> "${LOGPRG}"
# Kartenname für Beschreibung kürzen da max. 50 Zeichen erlaubt
KARTENNAMEDESCRIPTION=`echo ${KARTENNAME} | head -c12`
"${APP_java}" -Xmx${MEMORY} -server -jar ${APP_mkgmap}				\
	--description="${KARTENNAMEDESCRIPTION} OSM - ${ROHDATENDATUM} - Dirk Schimansky" \
	--country-name=${KARTENNAME} --country-abbr=${KARTENNAME}		\
	--style-file=${STARTDIR}/styles/mkgmap-style-OSM/				\
	--name-tag-list="name:de,name,int_name"							\
	--family-id=${FAMILYIDOSM} --product-id=1						\
	--series-name="${KARTENNAME}-OSM"								\
	--family-name="${KARTENNAME}-OSM"								\
	--area-name="${KARTENNAME}"										\
	--mapname="${FAMILYIDOSM}0001"									\
	--overview-mapname="${KARTENNAME}-OSM"							\
	--overview-mapnumber="${FAMILYIDOSM}0000"						\
	--gmapsupp --route												\
	--road-name-pois=0x640a											\
	--lower-case													\
	--draw-priority=25												\
	--latin1														\
	--make-opposite-cycleways										\
	--remove-short-arcs												\
	--generate-sea=multipolygon,extend-sea-sectors,close-gaps=6000	\
	--keep-going													\
	--index															\
	--max-jobs=${MAXPROCESSES}										\
	-c "${KARTENNAME}-OSM-template.args" "OSM.typ"					\
	>> "${LOGPRG}" 2>&1

FILESIZE=`ls -l gmapsupp.img | awk '{print$5}'`
echo " `perl round.pl ${FILESIZE}`" >> "${LOGSCRIPT}"

###
# Ergebnis wegschieben, damit POI erzeugt werden kann
echo "`date +%X`: Verschiebe \"gmapsupp.img\" nach \"${STARTDIR}/eigene_Karte_${KARTENNAME}/${KARTENNAME}-OSM.img\"" >> "${LOGSCRIPT}"
echo "\n###############################################################################################################" >> "${LOGPRG}"
echo "`date +%X`: Verschiebe \"gmapsupp.img\" nach \"${STARTDIR}/eigene_Karte_${KARTENNAME}/${KARTENNAME}-OSM.img\"" >> "${LOGPRG}"
echo "###############################################################################################################" >> "${LOGPRG}"
mv "gmapsupp.img" "${STARTDIR}/eigene_Karte_${KARTENNAME}/${KARTENNAME}-OSM.img"

################################################################################################################
################################################################################################################
############### POI-Karte erstellen ############################################################################
################################################################################################################
################################################################################################################

###
# Karte in Kacheln splitten (hier wird auch die template.args mit den IDs der einzelnen Kacheln erzeugt)
echo "" >> "${LOGSCRIPT}"
echo -n "`date +%X`: \"${KARTENNAME}.pbf\" für POI-Karte erneut in Kacheln splitten ..." >> "${LOGSCRIPT}"
echo "\n###############################################################################################################" >> "${LOGPRG}"
echo "`date +%X`: \"${KARTENNAME}.pbf\" für POI-Karte erneut in Kacheln splitten ..." >> "${LOGPRG}"
echo "###############################################################################################################" >> "${LOGPRG}"
"${APP_java}" -Xmx${MEMORY} -server -jar ${APP_splitter}				\
	--mapid=${FAMILYIDPOI}0001											\
	--mixed=yes															\
	--max-nodes=${MAX_NODES}											\
	--max-areas=8092													\
	--max-threads=${MAXPROCESSES}										\
	--keep-complete=true												\
	"${STARTDIR}/eigene_Karte_work/${KARTENNAME}.pbf"					\
	>> "${LOGPRG}" 2>&1
echo " ok!" >> "${LOGSCRIPT}"

###
# template.args dieses Splitterdurchlaufs sichern
mv -f "template.args" "${KARTENNAME}-POI-template.args"

echo -n "`date +%X`: Erzeuge POI-Karte \"gmapsupp.img\" (ohne Höhenlinien und OSM) ..." >> "${LOGSCRIPT}"
echo "\n###############################################################################################################" >> "${LOGPRG}"
echo "`date +%X`: Erzeuge POI-Karte \"gmapsupp.img\" (ohne Höhenlinien und OSM) ..." >> "${LOGPRG}"
echo "###############################################################################################################" >> "${LOGPRG}"

# Kartenname für Beschreibung kürzen da max. 50 Zeichen erlaubt
KARTENNAMEDESCRIPTION=`echo ${KARTENNAME} | head -c12`
"${APP_java}" -Xmx${MEMORY} -server -jar ${APP_mkgmap}				\
	--description="${KARTENNAMEDESCRIPTION} POI - ${ROHDATENDATUM} - OSM - DirkS" \
	--country-name=${KARTENNAME} --country-abbr=${KARTENNAME}		\
	--name-tag-list="name:de,name,int_name"							\
	--style-file=${STARTDIR}/styles/mkgmap-style-POI/				\
	--family-id=${FAMILYIDPOI} --product-id=1						\
	--series-name="${KARTENNAME}-POI"								\
	--family-name="${KARTENNAME}-POI"								\
	--area-name="${KARTENNAME}"										\
	--mapname="${FAMILYIDPOI}0001"									\
	--overview-mapname="${KARTENNAME}-POI"							\
	--overview-mapnumber="${FAMILYIDPOI}0000"						\
	--transparent													\
	--gmapsupp --route												\
	--lower-case													\
	--draw-priority=26												\
	--latin1														\
	--keep-going													\
	--max-jobs=${MAXPROCESSES}										\
	-c "${KARTENNAME}-POI-template.args" "POI.typ"					\
	>> "${LOGPRG}" 2>&1

FILESIZE=`ls -l gmapsupp.img | awk '{print$5}'`
echo " `perl round.pl ${FILESIZE}`" >> "${LOGSCRIPT}"

###
# Ergebnis wegschieben, damit SRTM erzeugt werden kann
echo "`date +%X`: Verschiebe \"gmapsupp.img\" nach \"${STARTDIR}/eigene_Karte_${KARTENNAME}/${KARTENNAME}-POI.img\"" >> "${LOGSCRIPT}"
echo "\n###############################################################################################################" >> "${LOGPRG}"
echo "`date +%X`: Verschiebe \"gmapsupp.img\" nach \"${STARTDIR}/eigene_Karte_${KARTENNAME}/${KARTENNAME}-POI.img\"" >> "${LOGPRG}"
echo "###############################################################################################################" >> "${LOGPRG}"
mv "gmapsupp.img" "${STARTDIR}/eigene_Karte_${KARTENNAME}/${KARTENNAME}-POI.img"

################################################################################################################
################################################################################################################
###################### SRTM-Daten downloaden und Höhenlinien neu erzeugen ######################################
################################################################################################################
################################################################################################################

###
# Höhenlinien-Karte erstellen
if [ -z "${EARTHEXPLORERUSER}" -o -z "${EARTHEXPLORERPASSWORD}" -o "${EARTHEXPLORERUSER}" = "dummy-user" -o "${EARTHEXPLORERPASSWORD}" = "dummy-password" ];then
	echo "" >> "${LOGSCRIPT}"
	echo "`date +%X`: \$EARTHEXPLORERUSER und \$EARTHEXPLORERUSER nicht eingetragen daher keine Höhenkartenerzeugung" >> "${LOGSCRIPT}"
	echo "\n###############################################################################################################" >> "${LOGPRG}"
	echo "`date +%X`: \$EARTHEXPLORERUSER und \$EARTHEXPLORERUSER nicht eingetragen daher keine Höhenkartenerzeugung" >> "${LOGPRG}"
	echo "###############################################################################################################" >> "${LOGPRG}"
else
	echo "" >> "${LOGSCRIPT}"
	echo "`date +%X`: SRTM-Daten für Höhenlinien holen und Kacheln erzeugen" >> "${LOGSCRIPT}"
	echo "\n###############################################################################################################" >> "${LOGPRG}"
	echo "`date +%X`: SRTM-Daten für Höhenlinien holen und Kacheln erzeugen" >> "${LOGPRG}"
	echo "###############################################################################################################" >> "${LOGPRG}"
	[ -d "${STARTDIR}/eigene_Karte_work/SRTM-work" ] && rm -r "${STARTDIR}/eigene_Karte_work/SRTM-work"
	mkdir "${STARTDIR}/eigene_Karte_work/SRTM-work"
	if [ -f "${STARTDIR}/polygones/${KARTENNAME}.poly" ];then
		echo "          --> nutze \"--polygon=${KARTENNAME}.poly\"" >> "${LOGSCRIPT}"
		BOUNDING="--polygon=${STARTDIR}/polygones/${KARTENNAME}.poly"
	else
		echo "          --> nutze \"--area=${LEFT}:${BOTTOM}:${RIGHT}:${TOP}\"" >> "${LOGSCRIPT}"
		BOUNDING="--area=${LEFT}:${BOTTOM}:${RIGHT}:${TOP}"
	fi

	${APP_phyghtmap}										\
		${BOUNDING}											\
		--earthexplorer-user="${EARTHEXPLORERUSER}"			\
		--earthexplorer-password="${EARTHEXPLORERPASSWORD}"	\
		--step=20											\
		--line-cat=200,100									\
		--no-zero-contour									\
		--corrx=0.0005										\
		--corry=0.0005										\
		--jobs=${MAXPROCESSES}								\
		--hgtdir=./											\
		-o "${STARTDIR}/eigene_Karte_work/SRTM-work/${KARTENNAME}-SRTM"		\
		>> "${LOGPRG}" 2>&1

	###
	# Garmin-Karte erzeugen
	echo -n "`date +%X`: Erzeuge Höhenlinienkarte \"${KARTENNAME}-SRTM.img\" ..." >> "${LOGSCRIPT}"
	echo "\n###############################################################################################################" >> "${LOGPRG}"
	echo "`date +%X`: Erzeuge Höhenlinienkarte \"${KARTENNAME}-SRTM.img\"" >> "${LOGPRG}"
	echo "###############################################################################################################" >> "${LOGPRG}"

	echo "#Hoehenlinien-Set" > "${STARTDIR}/eigene_Karte_work/${KARTENNAME}-SRTM-template.args"
	echo "" >> "${STARTDIR}/eigene_Karte_work/${KARTENNAME}-SRTM-template.args"
	echo "family-id: ${FAMILYIDSRTM}" >> "${STARTDIR}/eigene_Karte_work/${KARTENNAME}-SRTM-template.args"
	echo "product-id: 1" >> "${STARTDIR}/eigene_Karte_work/${KARTENNAME}-SRTM-template.args"
	echo "" >> "${STARTDIR}/eigene_Karte_work/${KARTENNAME}-SRTM-template.args"

	i=0
	for F in `ls -1 ${STARTDIR}/eigene_Karte_work/SRTM-work/*.osm`;do
		i=$((i+1))
		echo "" >> "${STARTDIR}/eigene_Karte_work/${KARTENNAME}-SRTM-template.args"
		echo "mapname: $((${FAMILYIDSRTM}0000+i))" >> "${STARTDIR}/eigene_Karte_work/${KARTENNAME}-SRTM-template.args"
		# Kartenname für Beschreibung kürzen da max. 50 Zeichen erlaubt
		KARTENNAMEDESCRIPTION=`echo ${KARTENNAME} | head -c12`
		echo "description: ${KARTENNAMEDESCRIPTION} SRTM - ${ROHDATENDATUM} - OSM - DirkS" >> "${STARTDIR}/eigene_Karte_work/${KARTENNAME}-SRTM-template.args"
		echo "input-file: ${F}"  >> "${STARTDIR}/eigene_Karte_work/${KARTENNAME}-SRTM-template.args"
	done
	echo "" >> "${STARTDIR}/eigene_Karte_work/${KARTENNAME}-SRTM-template.args"
	echo "# Ende Hoehenlinien-Set" >> "${STARTDIR}/eigene_Karte_work/${KARTENNAME}-SRTM-template.args"
	echo "" >> "${STARTDIR}/eigene_Karte_work/${KARTENNAME}-SRTM-template.args"

	KARTENNAMEDESCRIPTION=`echo ${KARTENNAME} | head -c12`
	"${APP_java}" -Xmx${MEMORY} -server -jar ${APP_mkgmap}				\
		--description="${KARTENNAMEDESCRIPTION} SRTM - ${ROHDATENDATUM} - OSM - DirkS" \
		--style-file=${STARTDIR}/styles/mkgmap-style-SRTM/				\
		--gmapsupp 														\
		--transparent													\
		--family-id=${FAMILYIDSRTM} --product-id=1 						\
		--draw-priority=27												\
		--series-name="${KARTENNAME}-SRTM"								\
		--family-name="${KARTENNAME}-SRTM"								\
		--mapname="${FAMILYIDSRTM}0001"									\
		--overview-mapname="${KARTENNAME}-SRTM"							\
		--overview-mapnumber="${FAMILYIDSRTM}0000"						\
		--area-name="${KARTENNAME}"										\
		--max-jobs=${MAXPROCESSES}										\
		-c "${STARTDIR}/eigene_Karte_work/${KARTENNAME}-SRTM-template.args"	"SRTM.typ"		\
		>> "${LOGPRG}" 2>&1

	FILESIZE=`ls -l gmapsupp.img | awk '{print$5}'`
	echo " `perl ${STARTDIR}/eigene_Karte_work/round.pl ${FILESIZE}`" >> "${LOGSCRIPT}"

	###
	# Ergebnis wegschieben, damit finale Karte erzeugt werden können
	echo "`date +%X`: Verschiebe \"gmapsupp.img\" nach \"${STARTDIR}/eigene_Karte_${KARTENNAME}/${KARTENNAME}-SRTM.img\"" >> "${LOGSCRIPT}"
	echo "\n################################################################################################################" >> "${LOGPRG}"
	echo "`date +%X`: Verschiebe \"gmapsupp.img\" nach \"${STARTDIR}/eigene_Karte_${KARTENNAME}/${KARTENNAME}-SRTM.img\"" >> "${LOGPRG}"
	echo "################################################################################################################" >> "${LOGPRG}"
	mv "gmapsupp.img" "${STARTDIR}/eigene_Karte_${KARTENNAME}/${KARTENNAME}-SRTM.img"

	###
	# weg damit
	rm -r "${STARTDIR}/eigene_Karte_work/SRTM-work"
fi
################################################################################################################
################################################################################################################
###################### aufräumen ###############################################################################
################################################################################################################
################################################################################################################
###
# aufräumen
if [ "${AUFRAEUMEN}" = "yes" ];then
	echo -n "\n`date +%X`: \"`pwd`\" aufräumen ..." >> "${LOGSCRIPT}"
	# Kartenrechnung
	for F in `ls -1 *`;do
		[ -z "`echo ${F} | awk -F. '{print $1}' | grep [a-zA-Z]`" ] && rm "${F}"
	done
	rm "${STARTDIR}/eigene_Karte_work/${KARTENNAME}-"*".img"
	rm "${STARTDIR}/eigene_Karte_work/${KARTENNAME}-"*".tdb"
	rm "${STARTDIR}/eigene_Karte_work/${KARTENNAME}-"*"-template.args"
	rm "${STARTDIR}/eigene_Karte_work/"*".typ"
	rm "${STARTDIR}/eigene_Karte_work/areas."*
	rm "${STARTDIR}/eigene_Karte_work/osmmap."*
	rm "${STARTDIR}/eigene_Karte_work/densities-out.txt"
	rm "${STARTDIR}/eigene_Karte_work/round.pl"
	rm "${STARTDIR}/eigene_Karte_work/${KARTENNAME}.pbf"
	echo " ok!" >> "${LOGSCRIPT}"
fi

###
# zurückspringen
cd "${STARTDIR}"

###
# Laufzeit ermitteln
STOPTIMEscript=`date +%s`
DAUERscript=$((STOPTIMEscript-STARTTIMEscript-DAUERdownload))
DAUERscript_hour=$((DAUERscript/3600))
DAUERscript_min=$(((DAUERscript-DAUERscript_hour*3600)/60))
DAUERscript_sec=$(((DAUERscript-DAUERscript_hour*3600-DAUERscript_min*60)))
[ ${DAUERscript_min} -lt 10 ] && DAUERscript_min="0${DAUERscript_min}"
[ ${DAUERscript_sec} -lt 10 ] && DAUERscript_sec="0${DAUERscript_sec}"
DAUERscript_txt="${DAUERscript_hour}:${DAUERscript_min}:${DAUERscript_sec}"
echo "" >> "${LOGSCRIPT}"
echo "\n################################################################################################################" >> "${LOGPRG}"
if [ ${DAUERdownload} -eq 0 ];then
	echo "`date +%X`: Laufzeit: ${DAUERscript_txt} (ohne Download)" >> "${LOGSCRIPT}"
	echo "`date +%X`: Karte \"${KARTENNAME}\" generiert in ${DAUERscript_txt} (ohne Download)" >> "${LOGPRG}"
else
	echo "`date +%X`: Laufzeit: ${DAUERscript_txt} (ohne Downloadzeit ${DAUERdownload_txt})" >> "${LOGSCRIPT}"
	echo "`date +%X`: Karte \"${KARTENNAME}\" generiert in ${DAUERscript_txt} (ohne Downloadzeit ${DAUERdownload_txt})" >> "${LOGPRG}"
fi
echo "" >> "${LOGSCRIPT}"
echo "################################################################################################################" >> "${LOGPRG}"

###
# die Logs festhalten
cp "${LOGSCRIPT}" "eigene_Karte_${KARTENNAME}/"
cp "${LOGPRG}" "eigene_Karte_${KARTENNAME}/"

###
# ich habe fertig!
exit 0

